import { EqualityFn, Selector } from './types';
/**
 * Internal implementation hook used by SyncStore.useSyncSelector.
 * Provides efficient memoized state selection with custom equality comparison.
 *
 * @template S The type of the complete state
 * @template Selected The type of the selected state slice
 *
 * @example
 * ```typescript
 * interface State {
 *   users: { id: number; name: string }[];
 *   settings: { theme: string };
 * }
 *
 * // Select specific users
 * const activeUsers = useSyncSelector(
 *   subscribe,
 *   getState,
 *   getServerState,
 *   (state: State) => state.users.filter(u => u.active),
 *   (prev, next) => prev.length === next.length
 * );
 *
 * // Select nested property
 * const theme = useSyncSelector(
 *   subscribe,
 *   getState,
 *   getServerState,
 *   (state: State) => state.settings.theme
 * );
 * ```
 */
export declare function useSyncSelector<S, Selected>(subscribe: (onStoreChange: () => void) => () => void, getState: () => S, getServerState: () => S, selector: Selector<S, Selected>, equalityFn?: EqualityFn<Selected>): Selected;
